@@ -6,13 +6,22 @@ class DataCreator(threading.Thread):
     def __init__(self, q, data_stream, device):
         super().__init__(daemon=True)
         self.q = q
-        self.in_stream = data_stream
+        try:
+            self.in_stream = iter(data_stream)
+        except TypeError:
+            self.in_stream = data_stream
+
         self.device = device
 
     def run(self):
-        for batch in self.in_stream:
-            batch = (x.to(self.device) for x in batch)
+        # for batch in self.in_stream:
+        while True:
+            try:
+                batch = next(self.in_stream)
+            except StopIteration:
+                break
 
+            batch = (x.to(self.device) for x in batch)
             self.q.put(batch)
 
 
